==> kcontacts-16.12.3.tar.xz: kcontacts-16.12.3/autotests/fieldgrouptest.h <==
/*
    This file is part of the KContacts framework.
    Copyright (c) 2016 Laurent Montel <montel@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
    version 2 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.

    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
    Boston, MA 02110-1301, USA.
*/

#ifndef FieldGroupTest_H
#define FieldGroupTest_H

#include <QObject>

class FieldGroupTest : public QObject
{
    Q_OBJECT
public:
    explicit FieldGroupTest(QObject *parent = Q_NULLPTR);
    ~FieldGroupTest();
private Q_SLOTS:
    void shouldHaveDefaultValue();
    void shouldAssignValue();
    void shouldAssignExternal();
    void shouldSerialized();
    void shouldEqualFieldGroup();
    void shouldParseFieldGroup();
    void shouldParseWithoutFieldGroup();
    void shouldCreateVCard();
    void shouldCreateVCardWithTwoLang();
    void shouldCreateVCardWithParameters();
    void shouldNotGenerateFieldGroupForVCard3();
};

#endif // FieldGroupTest_H

==> kcontacts-18.11.80.tar.xz: kcontacts-18.11.80/autotests/fieldgrouptest.h <==
/*
    This file is part of the KContacts framework.
    Copyright (C) 2016-2018 Laurent Montel <montel@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
    version 2 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.

    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
    Boston, MA 02110-1301, USA.
*/

#ifndef FieldGroupTest_H
#define FieldGroupTest_H

#include <QObject>

class FieldGroupTest : public QObject
{
    Q_OBJECT
public:
    explicit FieldGroupTest(QObject *parent = nullptr);
    ~FieldGroupTest();
private Q_SLOTS:
    void shouldHaveDefaultValue();
    void shouldAssignValue();
    void shouldAssignExternal();
    void shouldSerialized();
    void shouldEqualFieldGroup();
    void shouldParseFieldGroup();
    void shouldParseWithoutFieldGroup();
    void shouldCreateVCard();
    void shouldCreateVCardWithTwoLang();
    void shouldCreateVCardWithParameters();
    void shouldNotGenerateFieldGroupForVCard3();
};

#endif // FieldGroupTest_H
